/*
 * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef PENDINGTPLOGGERDATES_H
#define PENDINGTPLOGGERDATES_H

#include "KTp/Logger/pending-logger-dates.h"

namespace Tpl {
class PendingOperation;
}

class PendingTpLoggerDates : public KTp::PendingLoggerDates
{
    Q_OBJECT

  public:
    explicit PendingTpLoggerDates(const Tp::AccountPtr &account,
                                  const KTp::LogEntity &entity,
                                  QObject *parent = nullptr);
    ~PendingTpLoggerDates() override;

  private Q_SLOTS:
    void datesRetrieved(Tpl::PendingOperation *op);

};

#endif // PENDINGTPLOGGERDATES_H
